# xmrig-python
[![PyPi](https://img.shields.io/badge/PyPi-1.0.2-green?labelColor=026ab5&style=flat-square&logo=pypi&logoColor=ffffff&link=https://pypi.org/project/xmrig/)](https://pypi.org/project/xmrig/)
[![Python](https://img.shields.io/badge/Python-%203.8,%203.9,%203.10,%203.11,%203.12-green?labelColor=026ab5&style=flat-square&logo=pypi&logoColor=ffffff&link=https://pypi.org/project/xmrig/)](https://pypi.org/project/xmrig/)
![PyPI - Downloads](https://img.shields.io/pypi/dm/xmrig?label=PyPI%20Downloads)
![License](https://img.shields.io/github/license/CoulterStutz/python-xmrig?label=License&color=brightgreen)

A wrapper for the XMRig HTTP API

## Changelog
### 1.0.1
* Added the following properties
  * hashrate
  * uptime
  * accepted_jobs
  * rejected_jobs
  * paused
  * total_hashes
  * current_difficulty
  * pool_info
  * cpu_info
  * version
  * uptime_readable
  * memory_usage
  * load_average
### 1.0.2
* Added Access Token Support